Get the current Unplanned Hospital Visits data.
current_unplanned_hospital_vists_data(
.data,
.data_sets = c("Facility", "State", "National")
)Gets the current Unplanned Hospital Visits data from the current hospital data file.
The data that results from the current_hosp_data() function.
The default is: c(Facility","State","National"), which will bring back all of the data in the Unplanned Hospital Visits data sets that are in the file. You can choose from the following:
Facility
National
State
You can also pass things like c("state","Nation") as behind the scenes only
the Unplanned Hospital Visits data sets are available to the function to choose
from and grep is used to find matches with ignore.case = TRUE set.
Steven P. Sanderson II, MPH
This function will obtain the current Unplanned Hospital Visits data
from the output of the current_hosp_data() function, that is
the required input for the .data parameter. You can pass in a list of which
of those data sets you would like,
https://data.cms.gov/provider-data/topics/hospitals/
Other Hospital Data:
current_asc_data(),
current_asc_oas_cahps_data(),
current_comp_death_data(),
current_hai_data(),
current_hcahps_data(),
current_hosp_data(),
current_hvbp_data(),
current_ipfqr_data(),
current_maternal_data(),
current_medicare_hospital_spending_data(),
current_oqr_oas_cahps_data(),
current_outpatient_imaging_efficiency_data(),
current_payments_data(),
current_pch_hai_hospital_data(),
current_pch_hcahps_data(),
current_pch_oncology_measures_hospital_data(),
current_pch_outcomes_data(),
current_timely_and_effective_care_data(),
current_va_data()
if (FALSE) {
current_hosp_data() |>
current_unplanned_hospital_visits_data(.data_sets = c("State","National"))
}
Run the code above in your browser using DataLab